A backend module.
Structs
- Backend
Config - A structure of backend configuration.
Enums
- Backend
- A backend enumeration.
Functions
- finalize_
backend - Finalizes a backend for matrices.
- initialize_
backend - Initializes a backend for matrices with the file of backend configuration.
- initialize_
backend_ with_ config - Initializes a backend for matrices with the backend configuration.