pub fn initialize_backend<P: AsRef<Path>>(path: P) -> Result<()>Expand description
Initializes a backend for matrices with the file of backend configuration.
If the file of backend configuration doesn’t exist, this method uses the default field values of backend configuration.