pub enum Sig {
Var,
Fun(Vec<String>),
BuiltinFun(Vec<BuiltinFunArg>),
}Expand description
A signature structure.
The signature specifies whether a variable is a normal variable, a function, or a built-in function. If the variable is the function or the built-in funciton, the signature also specifies which arguments are passed to the function or the built-in function.
Variants
Var
A normal variable.
Fun(Vec<String>)
A function.
BuiltinFun(Vec<BuiltinFunArg>)
A built-in function.