pub struct DocGen { /* private fields */ }Expand description
A strucuture of documentation generator.
The documentation generator generates a documentation in a documentation directory of library. The documentation tree is used to a documentation generation by the documentation generator.
Implementations