pub struct DocTree { /* private fields */ }Expand description
A structure of documentation tree.
The documentation tree is a half result of documentation generation. The documentation tree has two module nodes which are a root modules of signature and a root module of documentation. These modules are used to finally generate a documentation.
Implementations
Sourceimpl DocTree
impl DocTree
Sourcepub fn new(
sig_root_mod: Arc<RwLock<ModNode<Sig, ()>>>,
doc_root_mod: Arc<RwLock<ModNode<String, Option<String>>>>,
) -> Self
pub fn new( sig_root_mod: Arc<RwLock<ModNode<Sig, ()>>>, doc_root_mod: Arc<RwLock<ModNode<String, Option<String>>>>, ) -> Self
Creates a documentation tree.
Sourcepub fn sig_root_mod(&self) -> &Arc<RwLock<ModNode<Sig, ()>>>
pub fn sig_root_mod(&self) -> &Arc<RwLock<ModNode<Sig, ()>>>
Returns the root module of signature.
Sourcepub fn doc_root_mod(&self) -> &Arc<RwLock<ModNode<String, Option<String>>>>
pub fn doc_root_mod(&self) -> &Arc<RwLock<ModNode<String, Option<String>>>>
Returns the root module of documentation.
Sourcepub fn read(&self) -> Result<DocTreeReadGuard<'_>>
pub fn read(&self) -> Result<DocTreeReadGuard<'_>>
Locks the reader-writer locks of root modules with shared read access.