pub struct DocTreeGen { /* private fields */ }Expand description
A structure of generator of documentation tree.
The generator of documentation tree takes a root module of documentation and then generates
a documentation tree. A root module of signature are generated from the syntax tree while
a generation of documentation tree. Applications of built-in function of running with
documentation allows to documention generation from other files than the main file of
library. By defaylt, the built-in function of running with documentation is runwithdoc.
Implementations
Sourceimpl DocTreeGen
impl DocTreeGen
Sourcepub fn new_with_script_dir_and_run_with_doc_ident(
doc_root_mod: Arc<RwLock<ModNode<String, Option<String>>>>,
script_dir: PathBuf,
run_with_doc_ident: String,
) -> Self
pub fn new_with_script_dir_and_run_with_doc_ident( doc_root_mod: Arc<RwLock<ModNode<String, Option<String>>>>, script_dir: PathBuf, run_with_doc_ident: String, ) -> Self
Creates a generator of documentation tree with the path to script directory and the identifier of built-in function of running with documentation.
Also, this method takes the root module of documentation that can have the module descriptions and the variable description.
Sourcepub fn new_with_script_dir(
doc_root_mod: Arc<RwLock<ModNode<String, Option<String>>>>,
script_dir: PathBuf,
) -> Self
pub fn new_with_script_dir( doc_root_mod: Arc<RwLock<ModNode<String, Option<String>>>>, script_dir: PathBuf, ) -> Self
Creates a generator of documentation tree with the path to script directory.
Sourcepub fn new(doc_root_mod: Arc<RwLock<ModNode<String, Option<String>>>>) -> Self
pub fn new(doc_root_mod: Arc<RwLock<ModNode<String, Option<String>>>>) -> Self
Creates a generator of documentation tree.
Sourcepub fn script_dir(&self) -> &Path
pub fn script_dir(&self) -> &Path
Returns the path to script directory.
Sourcepub fn run_with_doc_ident(&self) -> &str
pub fn run_with_doc_ident(&self) -> &str
Returns the identifier of built-in function of running with documentation.