Env

Struct Env 

pub struct Env { /* private fields */ }
An environment structure.

The environment is used by an interpreter and built-in functions and contains modules, variables, and a stack which are available by methods of the environment. Each stack element has a function module and local variables. Also, the environment has a script directory, a domain, the standard I/O enumerations, and a shared environment. The standard I/O enumerations determine which streams are used to the standard I/O in built-in functions.

Implementations

Source

impl Env

pub fn new_with_script_dir_and_domain_and_shared_env( root_mod: Arc<RwLock<ModNode<Value, ()>>>, script_dir: PathBuf, domain: Option<String>, shared_env: Arc<RwLock<SharedEnv>>, ) -> Self

Creates an environment with the path to script directory, the domain, and the shared environment.

Also, this method takes the root module that has the variables and other modules.

pub fn new(root_mod: Arc<RwLock<ModNode<Value, ()>>>) -> Self

Creates an environment.

See new_with_script_dir_and_domain_and_shared_env.

pub fn clone_without_stack(&self) -> Self

Clones the environment without the stack.

pub fn root_mod(&self) -> &Arc<RwLock<ModNode<Value, ()>>>

Returns the root module.

pub fn current_mod(&self) -> &Arc<RwLock<ModNode<Value, ()>>>

Returns the current module.

pub fn mod_idents(&self) -> &[String]

Returns the identifiers of current module.

pub fn stack( &self, ) -> &[(Arc<RwLock<ModNode<Value, ()>>>, BTreeMap<String, Value>)]

Returns the stack.

pub fn script_dir(&self) -> &Path

Returns the path to script directory.

pub fn domain(&self) -> Option<&str>

Returns the domain.

pub fn stdin(&self) -> &Input

Returns the standard input enumeration.

pub fn set_stdin(&mut self, input: Input)

Sets the standart input enumeration.

pub fn stdout(&self) -> &Output

Returns the standard output enumeration.

pub fn set_stdout(&mut self, output: Output)

Sets the standard output enumeration.

pub fn stderr(&self) -> &Output

Returns the standard error enumeration.

pub fn set_stderr(&mut self, output: Output)

Sets the standard error enumeration.

pub fn shared_env(&self) -> &Arc<RwLock<SharedEnv>>

Retunrs the shared environment.

pub fn add_and_push_mod(&mut self, ident: String) -> Result<bool>

Adds an empty module to the current module and then the empty module is set as the current module.

This method adds the empty, sets the empty module as current, and returns true if a module with the identifier doesn’t exist in the current module; otherwise this method returns false.

pub fn pop_mod(&mut self) -> Result<bool>

Sets the parent module of the current module is set as the current module.

This method sets the parent module as current and returns true if the current module has the parent module, otherwise this method returns false.

pub fn add_fun(&self, ident: String, fun: Arc<Fun>) -> Result<bool>

Adds the function.

This method adds the function and returns true if a function or a variable with the identifier doesn’t exist in the current module, otherwise this method returnsfalse.

pub fn push_fun_mod_and_local_vars( &mut self, fun_mod_idents: &[String], args: &[Arg], arg_values: &[Value], ) -> Result<bool>

Pushes the function module and a local variables to the stack for applies the function.

This method pushes the function module and the local variables and returns true if all identifiers of arguments are different, otherwise this method returns false.

pub fn pop_fun_mod_and_local_vars(&mut self)

Removes the last functoin module and the last local varables from stack.

pub fn reset(&mut self) -> Result<()>

Resets the environment.

pub fn var(&self, name: &Name) -> Result<Option<Value>>

Returns the variable value for the variable name if the variable exists, otherwise None.

pub fn set_var(&mut self, name: &Name, value: Value) -> Result<bool>

Sets the variable value for the variable name and returns true if the variable can be set, otherwise this method returns false.

pub fn remove_local_var(&mut self, ident: &String) -> bool

Removes the local variable with the identifier and returns true if the stack isn’t empty, otherwise this method returns false.