SharedEnv

Struct SharedEnv 

pub struct SharedEnv { /* private fields */ }
A structure of shared environment.

The shared environment is part of an environment that has global properities which can be shared between different environments. These global properties are library paths and documentation paths, arguments, used libraries, test suites, an event loop proxy, and other properties. The event loop proxy is used to communication to with the main thread from the windows.

Implementations

Source

impl SharedEnv

pub fn new_with_intr_checker_and_event_loop_proxy( lib_path: OsString, doc_path: OsString, args: Vec<String>, intr_checker: Arc<dyn IntrCheck + Send + Sync>, event_loop_proxy: Option<EventLoopProxy>, ) -> Self

Creates a shared environment with the interrruption checker and the event loop proxy.

Also, this method takes the paths of the libraries and the documentations and the arguments.

pub fn new_with_intr_checker( lib_path: OsString, doc_path: OsString, args: Vec<String>, intr_checker: Arc<dyn IntrCheck + Send + Sync>, ) -> Self

Creates a shared environment with the interrruption checker.

See new_with_intr_checker_and_event_loop_proxy.

pub fn new(lib_path: OsString, doc_path: OsString, args: Vec<String>) -> Self

Creates a shared environment.

See new_with_intr_checker_and_event_loop_proxy.

pub fn lib_path(&self) -> &OsStr

Returns the library paths.

pub fn doc_path(&self) -> &OsStr

Returns the documentation paths.

pub fn args(&self) -> &[String]

Returns the arguments.

pub fn used_libs(&self) -> &HashSet<String>

Returns the used libraries.

pub fn has_used_lib(&self, lib: &String) -> bool

Returns true if the shared environment has the used libraries, otherwise false.

pub fn add_used_lib(&mut self, lib: String)

Adds used library to the shared environment.

pub fn remove_used_lib(&mut self, lib: &String)

Removes used library from the shared environment.

pub fn test_suites(&self) -> &HashSet<Vec<String>>

Returns the test suites.

pub fn has_test_suite(&self, idents: &Vec<String>) -> bool

Returns true if the shared environment has the test suite, otherwise false.

pub fn add_test_suite(&mut self, idents: Vec<String>)

Adds test suite to the shared environment.

pub fn remove_test_suite(&mut self, idents: &Vec<String>)

Removes test suite from the shared environment.

pub fn intr_checker(&self) -> &Arc<dyn IntrCheck + Send + Sync>

Returns the interruption checker.

pub fn event_loop_proxy(&self) -> Option<&EventLoopProxy>

Returns the event loop proxy if the shared environment has the event loop proxy, otherwise None.

pub fn instant(&self) -> &Instant

Returns the measurement of system clock.