A filesytem module.
Functions
- conflicts
- Searches the path conflicts for the source directory and the destination directory.
- only_
one_ dir_ in_ dir - Returns the path to one directory in the directory if the directory has only one entry that is the directory, otherwise returns the path to the directory.
- paths_
in_ dir - Returns the paths in the directory for the optional depth.
- recursively_
copy - Recursively copies the files and/or the directories.
- recursively_
copy_ paths_ in_ dir - Recursively copies the files and/or the directories which are in the directories of paths.
- recursively_
remove - Recursively removes the files and/or the directories.
- recursively_
remove_ paths_ in_ dir - Recursively removes the files and/or the directories which are in the directories of paths.