Home

Struct Home 

pub struct Home { /* private fields */ }
A structure of home.

The home contains paths to the Unlab-gpu home directory, configuration files, history file. By default, the Unlab-gpu home directory is located in the home directory. Also, the binary paths, the library paths, and the documentation paths are in the home. The Unlab-gpu home directory or the work directory of current package has the binary directory, the library directory, and the documentation directory by default.

Implementations

Source

impl Home

pub fn new( home_dir: &Option<String>, bin_path: &Option<String>, lib_path: &Option<String>, doc_path: &Option<String>, is_work_dir: bool, ) -> Option<Self>

Creates a home.

This method takes the Unlab-gpu home directory, the paths. The binary directory, the library directory, and the documentation directory are located in the Unlab-gpu by default if the flag of work directory isn’t set, otherwise these directories are located in the work directory of current package by default.

pub fn home_dir(&self) -> &Path

Returns the path to the Unlab-gpu home directory.

pub fn backend_config_file(&self) -> &Path

Returns th path to the file of backend configuration.

pub fn history_file(&self) -> &Path

Returns the path to the history file.

pub fn pkg_config_file(&self) -> &Path

Returns the path to the file of package configuration.

pub fn bin_path(&self) -> &OsStr

Returns the binary paths.

pub fn lib_path(&self) -> &OsStr

Returns the library paths.

pub fn doc_path(&self) -> &OsStr

Returns the documentation paths.

pub fn add_dirs_to_bin_path( &mut self, dirs: &[String], ) -> Result<(), JoinPathsError>

Adds the directory paths to the binary paths.

Each directory path is pushed front to the binary paths. An addition order of directory paths is determined by the order of directory paths on the slice.

pub fn add_dirs_to_lib_path( &mut self, dirs: &[String], ) -> Result<(), JoinPathsError>

Adds the directory paths to the library paths.

See add_dirs_to_bin_path.

pub fn add_dirs_to_doc_path( &mut self, dirs: &[String], ) -> Result<(), JoinPathsError>

Adds the directory paths to the documentation paths.

See add_dirs_to_bin_path.