Interp

Struct Interp 

pub struct Interp { /* private fields */ }
An interpreter structure.

The interpreter interprets a syntax tree that can be produced by a parser while parsing tokens. If an interpreter error occurs while interpreting a script tree, the interpreter stores a stack trace that can contain functions and contains file positions. These functions are functons in which occurred the interpreter error. Also, the interpreter contains a return value that can be an error for an error propagation.

Implementations

Source

impl Interp

pub fn new() -> Self

Creates an interpreter.

pub fn stack_trace(&self) -> &[(Option<Value>, Pos)]

Returns the stack trace.

pub fn clear_stack_trace(&mut self)

Clears the stack trace.

pub fn ret_value(&self) -> &Value

Return the return value.

pub fn interpret(&mut self, env: &mut Env, tree: &Tree) -> Result<()>

Interprets the script tree.

pub fn apply_fun( &mut self, env: &mut Env, fun_value: &Value, arg_values: &[Value], ) -> Result<Value>

Applies the function to the arguments.

This method applies the function to the argument if the value is a function or a built-in function, otherwise returns an error.