IntrCheck

Trait IntrCheck 

pub trait IntrCheck {
    // Required method
    fn check(&self) -> Result<()>;
}
A trait of interruption checker.

The interruption checker is used by a checkintr built-in function to check whether an interruption is occurred. If the interruption is occurred, this built-in function returns an interruption error.

Required Methods

fn check(&self) -> Result<()>

Checks whether an interruption is occurred.

This method returns an interruption error if the interruption is occurred.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors