Token

Enum Token 

pub enum Token {
Show 58 variants LParen, RParen, LBracket, RBracket, LBrace, RBrace, DotLBracket, DotRBracket, Ques, Star, Slash, Plus, Minus, DotStar, DotSlash, DotPlus, DotMinus, Lt, GtEq, Gt, LtEq, Eq, EqEq, ExEq, Apos, Dot, Colon, ColonColon, Comma, Newline, And, Break, By, Continue, Else, End, False, Fill, For, Function, If, In, Inf, Module, Nan, None, Not, Or, Quit, Return, Root, To, True, While, Int(i64), Float(f32), String(String), Ident(String),
}
A token enumeration.

Variants



LParen

A ( token.



RParen

A ) token.



LBracket

A [ token.



RBracket

A ] token.



LBrace

A { token.



RBrace

A } token.



DotLBracket

A .[ token.



DotRBracket

A .] token.



Ques

A ? token.



Star

A * token.



Slash

A / token.



Plus

A + token.



Minus

A - token.



DotStar

A .* token.



DotSlash

A ./ token.



DotPlus

A .+ token.



DotMinus

A .- token.



Lt

A < token.



GtEq

A >= token.



Gt

A > token.



LtEq

A <= token.



Eq

A = token.



EqEq

A == token.



ExEq

A != token.



Apos

A ' token.



Dot

A . token.



Colon

A : token.



ColonColon

A :: token.



Comma

A , token.



Newline

A newline token or a ; token.



And

An and keyword.



Break

A break keyword.



By

A by keyword.



Continue

A continue keyword.



Else

An else keyword.



End

An end keyword.



False

A false keyword.



Fill

A fill keyword.



For

A for keyword.



Function

A function keyword.



If

An if keyword.



In

An in keyword.



Inf

An inf keyword.



Module

A module keyword.



Nan

A nan keyword.



None

A none keyword.



Not

A not keyword.



Or

An or keyword.



Quit

A quit keyword.



Return

A return keyword.



Root

A root keyword.



To

A to keyword.



True

A true keyword.



While

A while keyword.



Int(i64)

An integer number token.



Float(f32)

A floating-point number token.



String(String)

A string token.



Ident(String)

An identifier token.