ModNode

Struct ModNode 

pub struct ModNode<T, U> { /* private fields */ }
A structure of module node.

The module nodes creates a tree of modules that has modules and variables. The module node contains the modules which are the module nodes, the variables, and module value. Also, the module node has used modules and used variables. The used modules and the used variables are from other module, but also are available in the module node by identifiers.

Implementations

Source

impl<T, U> ModNode<T, U>

pub fn new(value: U) -> Self

Creates a module node with the module value.

pub fn used_mods(&self) -> &HashMap<String, ModNodeRef<T, U>>

Returns the used modules.

pub fn has_used_mod(&self, ident: &String) -> bool

Returns true if the module node has the used module, otherwise false.

pub fn used_mod(&self, ident: &String) -> Option<&ModNodeRef<T, U>>

Returns the reference to the used module if the module node has the used module, otherwise None.

pub fn add_used_mod( mod1: &Arc<RwLock<ModNode<T, U>>>, ident: String, used_mod: Arc<RwLock<ModNode<T, U>>>, ) -> Result<()>

Adds the used module to the module node.

pub fn remove_used_mod(&mut self, ident: &String)

Removes the used module from the module node.

pub fn used_vars(&self) -> &HashMap<String, UsedVar<T, U>>

Returns the used variable from the module node.

pub fn has_used_var(&self, ident: &String) -> bool

Returns true if the module node has the used variable, otherwise false.

pub fn used_var(&self, ident: &String) -> Option<&UsedVar<T, U>>

Returns the object of used variable if the module node has the used variable, otherwise None.

pub fn add_used_var( mod1: &Arc<RwLock<ModNode<T, U>>>, ident: String, used_var_mod: Arc<RwLock<ModNode<T, U>>>, used_var_ident: String, ) -> Result<()>

Adds the used variable to the module node.

pub fn remove_used_var(&mut self, ident: &String)

Removes the used variable from the module node.

pub fn mods(&self) -> &HashMap<String, Arc<RwLock<ModNode<T, U>>>>

Returns the modules.

pub fn has_mod(&self, ident: &String) -> bool

Returns true if the module node has the module, otherwise false.

pub fn mod1(&self, ident: &String) -> Option<&Arc<RwLock<ModNode<T, U>>>>

Returns the module if the module node has the module, otherwise None.

pub fn add_mod( parent: &Arc<RwLock<ModNode<T, U>>>, ident: String, child: Arc<RwLock<ModNode<T, U>>>, ) -> Result<()>

Adds the module to the module node.

pub fn remove_mod(&mut self, ident: &String) -> Result<()>

Removes the module from the module node.

pub fn vars(&self) -> &HashMap<String, T>

Returns the variables.

pub fn has_var(&self, ident: &String) -> bool

Returns true if the module node has the variable, otherwise false.

pub fn var(&self, ident: &String) -> Option<&T>

Returns the variable if the module node has the variable, otherwise None.

pub fn add_var(&mut self, ident: String, value: T)

Adds the variable to module node.

pub fn remove_var(&mut self, ident: &String)

Removes the variable from module node.

pub fn parent(&self) -> Option<Arc<RwLock<ModNode<T, U>>>>

Returns the parent if the module node if the module node has the parent, otherwise None.

pub fn value(&self) -> &U

Returns the module value.

pub fn set_value(&mut self, value: U)

Sets the module value.

pub fn mod_from( root: &Arc<RwLock<ModNode<T, U>>>, idents: &[String], are_used_mods: bool, ) -> Result<Option<Arc<RwLock<ModNode<T, U>>>>>

Returns the module for the identifiers of modules if the module exists, otherwise None.

If flag of used modules is set, the first identifier of module can refers to the used module.