pub struct UsedVar<T, U> { /* private fields */ }Expand description
A structure of object of used variable.
The used variables available in a module, but are defined in other module. This object refers the used variable by the referecne to module node and the variable identifier.
Implementations