Module parser

Module parser 

A parser module.

Structs

Parser
A parser structure.

Functions

parse
Parses the script is refered by the path.
parse_with_doc_root_mod
Parses the script is refered by the path with the root module of documentation.
parse_with_doc_root_mod_and_doc_current_mod
Parses the script is refered by the path with the root module of documentation and the current module of documentation.