Module pkg

Module pkg 

A package module.

Modules

bitbucket
A module of Bitbucket source.
github
A module of GitHub source.
gitlab
A module of GitLab source.

Structs

CustomSrc
A structure of custom source.
DocPaths
A structure of documentation paths.
EmptyPrinter
A structure of empty printer.
Manifest
A structure of package manifest.
Paths
A structure of paths.
PkgConfig
A strcuture of package configuration.
PkgInfo
A structure of package information.
PkgManager
A structure of package manager.
PkgName
A structure of package name.
StdPrinter
A structure of standard printer.
Versions
A structure of package versions.

Enums

SrcInfo
An enumeration of source information.
VersionSrcInfo
An enumeration of source information of version.

Constants

USER_AGENT_HTTP_HEADER
An User-Agent HTTP header for Curl.

Traits

Print
A printer trait.
A source trait.
SourceCreate
A trait of source factory.

Functions

cache_dir
Returns a path to the cache directory.
default_src_factories
Returns the factories of default sources.
download_pkg_file
Downloads the package archive for the specified package.
extract_pkg_file
Extracts the package archive for the specified package.
index_dir
Returns a path to the index directory.
load_opt_src_infos
Loads source informations from the file if the file exists, otherwise this function returns None.
load_opt_version_reqs
Loads version requirements from the file if the file exists, otherwise this function returns None.
load_opt_versions
Loads versions from the file if the file exists, otherwise this function returns None.
load_src_infos
Loads source informations from the file.
load_src_infos_or_empty
Loads source informations from the file if the file exists, otherwise this function returns an empty hash map.
load_version_reqs
Loads version requirements from the file.
load_version_reqs_or_empty
Loads version requirements from the file if the file exists, otherwise this function returns an empty hash map.
load_versions
Loads versions from the file.
load_versions_or_empty
Loads versions from the file if the file exists, otherwise this function returns an empty hash map.
pkg_cache_dir
Returns a path to the variable directory for the specified package.
pkg_dir
Returns a path to the package directory after extracting.
pkg_index_dir
Returns a path to the index directory for the specified package.
pkg_part_dir
Returns a path to the package directory while extracting.
pkg_tmp_dir
Returns a path to the temporary directory for the specified package.
read_src_infos
Reads source informations from the reader.
read_version_reqs
Reads version requirements from the reader.
read_versions
Reads versions from the reader.
save_src_infos
Saves the source informations to a file.
save_version_reqs
Saves the version requirements to a file.
save_versions
Saves the versions to a file.
tag_name_to_version
Converts the tag name to a version.
tmp_dir
Returns a path to the temporary director.
update_pkg_versions
Updates the package versions for the specified package.
var_dir
Returns a path to the variable directory.
version_to_tag_name
Converts the version to a tag name.
write_src_infos
Writes the source informations to the writer.
write_version_reqs
Writes the version requirements to the writer.
write_versions
Writes the versions to the writer.