load_src_infos_or_empty

Function load_src_infos_or_empty 

pub fn load_src_infos_or_empty<P: AsRef<Path>>(
    path: P,
) -> Result<HashMap<PkgName, SrcInfo>>
Loads source informations from the file if the file exists, otherwise this function returns an empty hash map.