load_versions_or_empty

Function load_versions_or_empty 

pub fn load_versions_or_empty<P: AsRef<Path>>(
    path: P,
) -> Result<HashMap<PkgName, Version>>
Loads versions from the file if the file exists, otherwise this function returns an empty hash map.