update_pkg_versions

Function update_pkg_versions 

pub fn update_pkg_versions<P: AsRef<Path>, F, G>(
    name: &PkgName,
    old_name: &Option<PkgName>,
    home_dir: P,
    is_update: bool,
    printer: &Arc<dyn Print + Send + Sync>,
    f: F,
    g: G,
) -> Result<BTreeSet<Version>>
where F: FnOnce() -> Result<Easy, Error>, G: FnOnce(&[u8]) -> Result<BTreeSet<Version>>,
Updates the package versions for the specified package.

This method overwrites the package versions if the package versions exist and the update flag is set, otherwise the package versios isn’t overwritten.