pub struct Manifest {
pub package: PkgInfo,
pub dependencies: Option<HashMap<PkgName, VersionReq>>,
pub constraints: Option<Arc<HashMap<PkgName, VersionReq>>>,
pub sources: Option<Arc<HashMap<PkgName, SrcInfo>>>,
}Expand description
A structure of package manifest.
The package manifest contains basic informations about package for example a package name, package description, and package dependencies. These informations can be used to package installation.
Fields
package: PkgInfoA package information.
dependencies: Option<HashMap<PkgName, VersionReq>>Package dependencies.
constraints: Option<Arc<HashMap<PkgName, VersionReq>>>Package constraints.
sources: Option<Arc<HashMap<PkgName, SrcInfo>>>Custrom sources.
Implementations