PkgManager

Struct PkgManager 

pub struct PkgManager { /* private fields */ }
A structure of package manager.

The package manager is used to install packages and remove package. Default sources can be used to download and extract the packages by the package manager. The package manager installs the packages to the Unlab-gpu home directory by default where they are available for a user. Also, the packages can be installed as dependencies of current package by default.

Implementations

Source

impl PkgManager

pub fn new( home_dir: PathBuf, work_dir: PathBuf, bin_dir: PathBuf, lib_dir: PathBuf, doc_dir: PathBuf, src_factories: Vec<Arc<dyn SourceCreate + Send + Sync>>, printer: Arc<dyn Print + Send + Sync>, ) -> Result<Self>

Creates a package manager.

This method takes paths to the Unlab-gpu home directory, the work directory, the binary dirtectory, the library directory, and the documentation directory. The factories of default soruces which allows to access to the package. Also, this method takes the printer that prints messages. If the packages isn’t installed as the dependencies for the current package, the path of work directory should be the path to the the Unlab-gpu home directory.

pub fn home_dir(&self) -> &Path

Returns the path to the Unlab-gpu home directory.

pub fn work_dir(&self) -> &Path

Returns the path to the work directory of current package.

pub fn bin_dir(&self) -> &Path

Returns the path to the binary directory.

pub fn lib_dir(&self) -> &Path

Returns the path to the library directory.

pub fn doc_dir(&self) -> &Path

Returns the path to the documentation directory.

pub fn locks(&self) -> &HashMap<PkgName, Version>

Returns the locked versions of packages

pub fn set_locks(&mut self, locks: HashMap<PkgName, Version>)

Sets the locked versions of packages.

pub fn load_locks(&mut self) -> Result<()>

Loads the locked versions of packages.

pub fn save_locks(&self) -> Result<()>

Saves the locked versions of packages.

pub fn save_locks_from_pkg_versions(&self) -> Result<()>

Saves the locked version packages from the database.

pub fn constraints(&self) -> &Arc<HashMap<PkgName, VersionReq>>

Returns the constraints.

pub fn set_constraints( &mut self, constraints: Arc<HashMap<PkgName, VersionReq>>, )

Sets the constraints.

pub fn load_constraints(&mut self) -> Result<()>

Loads the constraints.

pub fn sources(&self) -> &Arc<HashMap<PkgName, SrcInfo>>

Returns the custom sources.

pub fn set_sources(&mut self, sources: Arc<HashMap<PkgName, SrcInfo>>)

Sets the custom sources.

pub fn load_sources(&mut self) -> Result<()>

Loads the custom sources.

pub fn src_factories(&self) -> &[Arc<dyn SourceCreate + Send + Sync>]

Returns the factories of sources.

pub fn printer(&self) -> &Arc<dyn Print + Send + Sync>

Returns the printer.

pub fn manifest() -> Result<Manifest>

Loads the manifest of current package.

pub fn save_manifest(manifest: &Manifest) -> Result<()>

Saves the manifest of current package.

pub fn reset(&mut self)

Resets the package manager.

pub fn constraints_file(&self) -> PathBuf

Returns the path to the constraints.

pub fn sources_file(&self) -> PathBuf

Returns the path to the custom sources.

pub fn work_var_dir(&self) -> PathBuf

Returns the path to the variable directory in the work directory.

pub fn work_tmp_dir(&self) -> PathBuf

Returns the path to the temporary directory in the work directory.

pub fn info_dir(&self) -> PathBuf

Returns the path to the information directory.

pub fn new_part_info_dir(&self) -> PathBuf

Returns the path to the information directory while pre-installing.

pub fn new_info_dir(&self) -> PathBuf

Returns the path to the information directory while installing.

pub fn pkg_info_dir(&self, name: &PkgName) -> PathBuf

Returns the path to the information directory for the specified package.

pub fn pkg_new_part_info_dir(&self, name: &PkgName) -> PathBuf

Returns the path to the information directory while pre-installing for the specified package.

pub fn pkg_new_info_dir(&self, name: &PkgName) -> PathBuf

Returns the path to the information directory while installing for the specified package.

pub fn pkg_tmp_doc_dir(&self, name: &PkgName, version: &Version) -> PathBuf

Returns the path to the documentation directory in the temporary directory for the specified package.

pub fn create_source( &self, name: &PkgName, ) -> Result<Box<dyn Source + Send + Sync>>

Creates a source for the specified package.

pub fn pkg_versions(&self) -> Result<Vec<(PkgName, Version)>>

Returns the package versions.

pub fn pkg_versions_in<F>(&self, f: F) -> Result<()>
where F: FnMut(&PkgName, &Version) -> Result<()>,

Calls the function for each package version.

pub fn pkg_version(&self, name: &PkgName) -> Result<Option<Version>>

Returns the package version if the package is installed, otherwise None.

pub fn pkg_manifest(&self, name: &PkgName) -> Result<Option<Manifest>>

Returns the package manifest if the package is installed, otherwise None.

pub fn pkg_dependents( &self, name: &PkgName, ) -> Result<Option<HashMap<PkgName, VersionReq>>>

Returns the package dependents if the package is installed, otherwise None.

pub fn pkg_paths(&self, name: &PkgName) -> Result<Option<Paths>>

Returns the package paths if the package is installed, otherwise None.

pub fn update(&self, names: &[PkgName]) -> Result<()>

Updates the versions of packages.

pub fn install( &mut self, names: &[PkgName], is_update: bool, is_force: bool, is_doc: bool, ) -> Result<()>

Installs the specified packages with depedencies.

This method overwrites the versions of packages if the update flag is set, otherwise the versions of the packages aren’t updated. If the force flag is set, the packages with the dependencies are reinstalled. The documentations are installed for the packages if the documentation is set, otherwise the documentation aren’t installed.

pub fn install_deps( &mut self, is_update: bool, is_force: bool, is_doc: bool, ) -> Result<()>

Installs the dependencies for the current package.

The unused packages are automatically removed from the work directory. See also install.

pub fn remove(&mut self, names: &[PkgName]) -> Result<()>

Removes the specified packages.

pub fn check_last_op(&self, are_deps: bool) -> Result<()>

Checks whether the preparation to the last operation or the last operations was interrupted.

If the preparation to the last operation or the last operation was interrupted, this method returns an error with the appropriate message.

pub fn cont(&self, is_doc: bool, are_deps: bool) -> Result<()>

Continues the interrupted last operation.

pub fn clean(&self) -> Result<()>

Cleans after the interrupted preparation to the last operation.

pub fn update_all(&self) -> Result<()>

Updates the versions of all packages.

pub fn install_all( &mut self, is_update: bool, is_force: bool, is_doc: bool, ) -> Result<()>

Reinstalls all packages.

See install.

pub fn generate_doc(&self) -> Result<()>

Generates a documentation for the current package.

pub fn generate_std_doc(&self) -> Result<()>

Generates a documentation of the standard built-in functions.