pub struct PkgName { /* private fields */ }Expand description
A structure of package name.
The package name often consists an account and a repository name. The account often contains the git hosting service and a login. The package name should contain one slash character.
Implementations