HistogramValue

Enum HistogramValue 

pub enum HistogramValue {
    Bool(bool),
    Int(i64),
    Float(f32),
    String(Box<String>),
}
A structure of histogram value.

Variants



Bool(bool)

A boolean value.



Int(i64)

An integer number.



Float(f32)

A floating-point number.



String(Box<String>)

A string.

Implementations

Source

impl HistogramValue

pub fn to_bool(&self) -> bool

Converts any value to a boolean value.

pub fn to_i64(&self) -> i64

Converts any value to an integer number.

pub fn to_f32(&self) -> f32

Converts any value to a floating-point number.

pub fn to_opt_bool(&self) -> Option<bool>

Converts the value to a boolean value if the value is an boolean type, otherwise this method returns None.

pub fn to_opt_i64(&self) -> Option<i64>

Converts the value to an integer number if the value is an integer type or floating-point type, otherwise this method returns None.

pub fn to_opt_f32(&self) -> Option<f32>

Converts the value to a floating-point number if the value is an integer type or floating-point type, otherwise this method returns None.

pub fn to_opt_string(&self) -> Option<String>

Converts the value to a string if the value is a string type, otherwise this method returns None.