pub enum PlotterAppEvent {
Plot(Arc<Plot>, Sender<Option<WindowId>>),
Quit,
}Expand description
An enumeration of plotter application event.
The plotter application events are used by a thread of main loop to communication with a thread of plotter application.
Variants