TestResult

Struct TestResult 

pub struct TestResult { /* private fields */ }
A structure of test result.

The test result can be a success or a failure. A test error with a stack trace is in the result test if the test result is failure. Also, data from the standard output and the standard error stores in cursors which are in the test result.

Implementations

Source

impl TestResult

pub fn new( error_pair: Option<(Error, Vec<(Option<Value>, Pos)>)>, stdout: Option<Arc<RwLock<Cursor<Vec<u8>>>>>, stderr: Option<Arc<RwLock<Cursor<Vec<u8>>>>>, ) -> TestResult

Creates a test result.

pub fn is_success(&self) -> bool

Returns true if the test result is success, otherwise false.

pub fn is_failure(&self) -> bool

Returns true if the test result is failure, otherwise false.

pub fn error_pair(&self) -> Option<&(Error, Vec<(Option<Value>, Pos)>)>

Returns the test error with the stack trace if the test result is failure, otherwise None.

pub fn stdout(&self) -> Option<&Arc<RwLock<Cursor<Vec<u8>>>>>

Returns the cursor of standard output if the test result has the cursor of standard output, otherwise None.

pub fn stderr(&self) -> Option<&Arc<RwLock<Cursor<Vec<u8>>>>>

Returns the cursor of standard error if the test result has the cursor of standard error, otherwise None.

pub fn has_stdout_data(&self) -> Result<bool>

Returns true if the test result has data from the standard output, otherwise false.

pub fn has_stderr_data(&self) -> Result<bool>

Returns true if the test result has data from the standard error, otherwise false.