Tester

Struct Tester 

pub struct Tester { /* private fields */ }
A tester structure.

The tester tests a library or libraries by running the tests which were written by a programmer. The test results can be collected by the tester in order to print the test results for the programmer.

Implementations

Source

impl Tester

pub fn new( root_mod: Arc<RwLock<ModNode<Value, ()>>>, lib_path: OsString, doc_path: OsString, printer: Arc<dyn Print + Send + Sync>, are_stdout_cursors: bool, are_stderr_cursors: bool, ) -> Self

Creates a tester.

This method the root module, the library paths, the documentation library and the printer that prints the messages. The flags of cursors determines whether data from the standard output and the standard error are collect by the cursors.

pub fn root_mod(&self) -> &Arc<RwLock<ModNode<Value, ()>>>

Returns the root module.

pub fn shared_env(&self) -> &Arc<RwLock<SharedEnv>>

Returns the shared environment.

pub fn stack_trace(&self) -> &[(Option<Value>, Pos)]

Returns the stack trace.

pub fn test_results(&self) -> &[((Vec<String>, String), TestResult)]

Returns the test results.

pub fn printer(&self) -> &Arc<dyn Print + Send + Sync>

Returns the printer.

pub fn has_stdout_cursors(&self) -> bool

Returns the flag of cursor of standard output.

pub fn has_stderr_cursors(&self) -> bool

Returns the flag of cursor of standard error.

pub fn load(&mut self) -> Result<()>

Loads tests.

pub fn run_test(&mut self, idents: &Vec<String>, ident: &String) -> Result<()>

Runs the specified test by the idenfiers of modules and the function identifer.

pub fn run_tests_in_test_suite(&mut self, idents: &Vec<String>) -> Result<()>

Runs the tests in the specified test suite by the identifiers of modules.

pub fn run_all_tests(&mut self) -> Result<()>

Runs all tests.

pub fn print_empty_line(&self)

Prints an empty line.

pub fn print_successes(&self) -> Result<()>

Prints the test successes.

pub fn print_failures(&self) -> Result<()>

Prints the test failures.

pub fn print_test_counts(&self)

Prints the number of passed tests and the number of failed tests.