pub enum Name {
Abs(Vec<String>, String),
Rel(Vec<String>, String),
Var(String),
}Expand description
An enumeration of variable name.
Variants
Abs(Vec<String>, String)
An absolute name with identifiers of modules and a variable identifier.
Rel(Vec<String>, String)
A relative name with identifiers of modules and a variable identifier.
Var(String)
A name with one identifier.