Module utils

Module utils 

A module of utilities.

Structs

PushbackIter
A structure of pushback iterator.

Functions

eprint_error
Prints the error to the standard error.
eprint_error_with_stack_trace
Prints the error with the stac trace to the standard error.
matrix_abs
Calculates absolute values of the a matrix elements.
matrix_acos
Calculates arccosine function for the a matrix.
matrix_acosh
Calculates inverse hyperbolic cosine function for the a matrix.
matrix_add
Adds the b matrix to the a matrix.
matrix_add_for_scalar
Adds the b scalar to the a matrix.
matrix_asin
Calculates arcsine function for the a matrix.
matrix_asinh
Calculates inverse hyperbolic sine function for the a matrix.
matrix_atan
Calculates arctangent function for the a matrix.
matrix_atan2
Calculates arctangent function for the a matrix elements and the b matrix elements.
matrix_atan2_for_scalar
Calculates arctangent function for the a matrix elements and the b scalar.
matrix_atanh
Calculates inverse hyperbolic tangent function for the a matrix.
matrix_backend_name
Returns the backend name.
matrix_ceil
Calculates ceil function for the a matrix.
matrix_cos
Calculates cosine function for the a matrix.
matrix_cosh
Calculates hyperbolic cosine function for the a matrix.
matrix_create_and_set_elems
Creates a matrix and sets the matrix elements.
matrix_create_and_set_zeros
Creates a matrix and sets the matrix elements on zeros.
matrix_div_elems
Divides the a matrix elements by the b matrix.
matrix_div_for_scalar
Divides the a matrix by the b scalar.
matrix_elems_and_transpose_flag
Returns the elements and the transpose flag of matrix.
matrix_exp
Calculates exponential function for the a matrix elements.
matrix_floor
Calculates floor function for the a matrix.
matrix_ln
Calculates natural logarithm of the a matrix elements.
matrix_log2
Calculates base 2 logarithm of the a matrix elements.
matrix_log10
Calculates base 10 logarithm of the a matrix elements.
matrix_max
Finds maximum values between the a matrix elements and the b matrix elements.
matrix_max_for_scalar
Finds maximum values between the a matrix elements and the b scalar.
matrix_min
Finds minimum values between the a matrix elements and the b matrix elements.
matrix_min_for_scalar
Finds minimum values between the a matrix elements and the b scalar.
matrix_mul
Multiplies the a matrix by the b matrix.
matrix_mul_elems
Multiplies the a matrix elements by the b matrix.
matrix_mul_for_scalar
Multiplies the a matrix by the b scalar.
matrix_pow
Raises the a matrix elements to the power of the b matrix elements.
matrix_pow_for_scalar
Raises the a matrix elements to the power of the b scalar.
matrix_ratan2_for_scalar
Calculates arctangent function for the b scalar and the a matrix elements.
matrix_rdiv_for_scalar
Divides the b scalar by the a matrix elements.
matrix_really_transpose
Indeed transposes the a matrix.
matrix_repeat
Repeats the a vector as column or a row.
matrix_round
Calculates round function for the a matrix.
matrix_rpow_for_scalar
Raises the b scalar to the power of the a matrix elements.
matrix_rsub_for_scalar
Subtracts the a matrix from the b scalar.
matrix_sigmoid
Calculates sigmoid function for the a matrix.
matrix_signum
Calculates signum function for the a matrix.
matrix_sin
Calculates sine function for the a matrix.
matrix_sinh
Calculates hyperbolic sine function for the a matrix.
matrix_softmax
Calculates softmax function for the a matrix.
matrix_sqrt
Calculates square roots of the a matrix elements.
matrix_sub
Subtracts the b matrix from the a matrix.
matrix_sub_for_scalar
Subtracts the b scalar from the a matrix.
matrix_swish
Calculates swish function for the a matrix.
matrix_tan
Calculates tangent function for the a matrix.
matrix_tanh
Calculates hyperbolic tangent function for the a matrix.
matrix_to_matrix_array
Converts the a matrix to the matrix array.
matrix_trunc
Calculates trunc function for the a matrix.
mutex_lock
Locks the mutex.
receiver_recv
Receives an object from the receiver.
rw_lock_read
Locks the reader-writer lock with shared read access.
rw_lock_write
Locks the reader-writer lock with exclusive write access.
str_to_ident
Converts the string slice to an identifier.
str_to_url_name
Converts the string slice to an URL name.
str_without_crlf
Returns the string slice without the LF character and the CRLF character sequence.