SingleVersionReq

Enum SingleVersionReq 

pub enum SingleVersionReq {
    Wildcard,
    Pair(VersionOp, Version),
}
An enumeration of single version requirement.

The single version requirement can have one version with a version operator or can be a wildcard. A version requirement uses many single version requirements which can be matched to a version while matching.

Variants



Wildcard

A wildcard.



Pair(VersionOp, Version)

A pair of version operator and version.

Implementations

Source

impl SingleVersionReq

pub fn parse(s: &str) -> Result<Self>

Parsers the string slice to a single version requirement.

pub fn matches(&self, version: &Version) -> bool

Matches the single version requirement to the version.

This method returns true if the single version requirement is matched to the version, otherwise false.