pub struct Version { /* private fields */ }Expand description
A version structure.
The version structure has version field and fields compatible with SemVer.
Implementations
Sourceimpl Version
impl Version
Sourcepub fn new(
version: String,
numeric_idents: Vec<u32>,
pre_release_idents: Option<Vec<PreReleaseIdent>>,
build_idents: Option<Vec<String>>,
) -> Self
pub fn new( version: String, numeric_idents: Vec<u32>, pre_release_idents: Option<Vec<PreReleaseIdent>>, build_idents: Option<Vec<String>>, ) -> Self
Creates a version.
Sourcepub fn numeric_idents(&self) -> &[u32]
pub fn numeric_idents(&self) -> &[u32]
Returns the numeric identifiers.
Sourcepub fn pre_release_idents(&self) -> Option<&[PreReleaseIdent]>
pub fn pre_release_idents(&self) -> Option<&[PreReleaseIdent]>
Retursn the pre-release identifiers.
Sourcepub fn build_idents(&self) -> Option<&[String]>
pub fn build_idents(&self) -> Option<&[String]>
Returns the build indentifiers.
Sourcepub fn eq_numeric_idents(&self, version: &Version, count: usize) -> bool
pub fn eq_numeric_idents(&self, version: &Version, count: usize) -> bool
Returns true if the numeric identifiers of versions are equal for the specified number
of numeric identifiers, otherwise false.