VersionReq

Struct VersionReq 

pub struct VersionReq { /* private fields */ }
A structure of version requirement.

The version requirement can be matched to the version and can contain many single version requirements which can be matched to version while matching. The version requirements are used to check versions by a package manager and a reqver built-in function.

Implementations

Source

impl VersionReq

pub fn new(single_reqs: Vec<SingleVersionReq>) -> Self

Creates a version requirement.

pub fn parse(s: &str) -> Result<Self>

Parsers the string slice to a version requirement.

pub fn single_reqs(&self) -> &[SingleVersionReq]

Returns the single version requirements.

pub fn matches(&self, version: &Version) -> bool

Matches the version requirement to the version.

This method returns true if the version requirement is matched to the version, otherwise false.