Crate unlab_gpu

Crate unlab_gpu 

Micro neural scripting language for GPU is simple scripting language that operates on matrices.

This scripting language is implemented in the Unlab-gpu library that uses the Unmtx-gpu library to operate on matrices. Also, the Unlab-gpu library implements a package manager that can be used to install and remove packages.

The Unlab-gpu library is a very modular library that contains the following components for this scripting language:

  • lexer
  • parser
  • interpreter
  • standard built-in functions
  • getopts
  • plotter
  • documentation generator
  • package manager
  • tester

This scripting language is extensible by the Unlab-gpu library. The Unlab-gpu library allows to extend this scripting language with own built-in functions. The standard built-in functions of this scripting language also can be replaced by own built-in functions.

Re-exports

pub use backend::initialize_backend;
pub use backend::finalize_backend;
pub use builtins::add_std_builtin_funs;
pub use env::Env;
pub use error::Error;
pub use error::Result;
pub use home::Home;
pub use interp::Interp;
pub use main_loop::main_loop;
pub use mod_node::ModNode;
pub use parser::parse;
pub use parser::parse_with_doc_root_mod;
pub use parser::parse_with_doc_root_mod_and_doc_current_mod;
pub use tree::Tree;
pub use value::Value;
pub use ctrlc;
pub use curl;
pub use serde;
pub use serde_json;
pub use toml;
pub use unmtx_gpu as matrix;
pub use winit;

Modules

backend
A backend module.
builtin_doc
A module of documentation of built-in functions.
builtins
A module of built-in functions.
dfs
A module of DFS algorithm.
doc
A documentation module.
env
An environment module.
error
An error module.
fs
A filesytem module.
getopts
A module of getopts.
getopts_doc
A module of documentation of getopts.
home
A home module.
interp
An interpreter module.
intr
An interruption module.
io
An I/O module.
lexer
A lexer module.
main_loop
A module of main loop.
mod_node
A module of module node.
parser
A parser module.
pkg
A package module.
pkg_cmds
A module of package commands.
plot
A plotting module.
plot_doc
A module of plotting documentation.
tester
A tester module.
tree
A module of syntax tree.
utils
A module of utilities.
value
A value module.
version
A version module.