Module backend

Module backend 

A backend module.

Structs

BackendConfig
A structure of backend configuration.

Enums

Backend
A backend enumeration.

Functions

finalize_backend
Finalizes a backend for matrices.
initialize_backend
Initializes a backend for matrices with the file of backend configuration.
initialize_backend_with_config
Initializes a backend for matrices with the backend configuration.