Module fs

Module fs 

A filesytem module.

Functions

conflicts
Searches the path conflicts for the source directory and the destination directory.
only_one_dir_in_dir
Returns the path to one directory in the directory if the directory has only one entry that is the directory, otherwise returns the path to the directory.
paths_in_dir
Returns the paths in the directory for the optional depth.
recursively_copy
Recursively copies the files and/or the directories.
recursively_copy_paths_in_dir
Recursively copies the files and/or the directories which are in the directories of paths.
recursively_remove
Recursively removes the files and/or the directories.
recursively_remove_paths_in_dir
Recursively removes the files and/or the directories which are in the directories of paths.