pub fn conflicts<P: AsRef<Path>, Q: AsRef<Path>>(
src: P,
dst: Q,
ignored_paths: &HashSet<PathBuf>,
depth: Option<usize>,
) -> Result<(Vec<PathBuf>, Vec<PathBuf>)>Expand description
Searches the path conflicts for the source directory and the destination directory.
This function returns the conflict paths and the paths of source directory for the optional depth. The path of source directory are compared with the path of destination directory. If these paths are same, there occurs the path conflict.