pub struct ModNode<T, U> { /* private fields */ }Expand description
A structure of module node.
The module nodes creates a tree of modules that has modules and variables. The module node contains the modules which are the module nodes, the variables, and module value. Also, the module node has used modules and used variables. The used modules and the used variables are from other module, but also are available in the module node by identifiers.
Implementations
Sourceimpl<T, U> ModNode<T, U>
impl<T, U> ModNode<T, U>
Sourcepub fn used_mods(&self) -> &HashMap<String, ModNodeRef<T, U>>
pub fn used_mods(&self) -> &HashMap<String, ModNodeRef<T, U>>
Returns the used modules.
Sourcepub fn has_used_mod(&self, ident: &String) -> bool
pub fn has_used_mod(&self, ident: &String) -> bool
Returns true if the module node has the used module, otherwise false.
Sourcepub fn used_mod(&self, ident: &String) -> Option<&ModNodeRef<T, U>>
pub fn used_mod(&self, ident: &String) -> Option<&ModNodeRef<T, U>>
Returns the reference to the used module if the module node has the used module,
otherwise None.
Sourcepub fn add_used_mod(
mod1: &Arc<RwLock<ModNode<T, U>>>,
ident: String,
used_mod: Arc<RwLock<ModNode<T, U>>>,
) -> Result<()>
pub fn add_used_mod( mod1: &Arc<RwLock<ModNode<T, U>>>, ident: String, used_mod: Arc<RwLock<ModNode<T, U>>>, ) -> Result<()>
Adds the used module to the module node.
Sourcepub fn remove_used_mod(&mut self, ident: &String)
pub fn remove_used_mod(&mut self, ident: &String)
Removes the used module from the module node.
Sourcepub fn used_vars(&self) -> &HashMap<String, UsedVar<T, U>>
pub fn used_vars(&self) -> &HashMap<String, UsedVar<T, U>>
Returns the used variable from the module node.
Sourcepub fn has_used_var(&self, ident: &String) -> bool
pub fn has_used_var(&self, ident: &String) -> bool
Returns true if the module node has the used variable, otherwise false.
Sourcepub fn used_var(&self, ident: &String) -> Option<&UsedVar<T, U>>
pub fn used_var(&self, ident: &String) -> Option<&UsedVar<T, U>>
Returns the object of used variable if the module node has the used variable, otherwise
None.
Sourcepub fn add_used_var(
mod1: &Arc<RwLock<ModNode<T, U>>>,
ident: String,
used_var_mod: Arc<RwLock<ModNode<T, U>>>,
used_var_ident: String,
) -> Result<()>
pub fn add_used_var( mod1: &Arc<RwLock<ModNode<T, U>>>, ident: String, used_var_mod: Arc<RwLock<ModNode<T, U>>>, used_var_ident: String, ) -> Result<()>
Adds the used variable to the module node.
Sourcepub fn remove_used_var(&mut self, ident: &String)
pub fn remove_used_var(&mut self, ident: &String)
Removes the used variable from the module node.
Sourcepub fn has_mod(&self, ident: &String) -> bool
pub fn has_mod(&self, ident: &String) -> bool
Returns true if the module node has the module, otherwise false.
Sourcepub fn mod1(&self, ident: &String) -> Option<&Arc<RwLock<ModNode<T, U>>>>
pub fn mod1(&self, ident: &String) -> Option<&Arc<RwLock<ModNode<T, U>>>>
Returns the module if the module node has the module, otherwise None.
Sourcepub fn add_mod(
parent: &Arc<RwLock<ModNode<T, U>>>,
ident: String,
child: Arc<RwLock<ModNode<T, U>>>,
) -> Result<()>
pub fn add_mod( parent: &Arc<RwLock<ModNode<T, U>>>, ident: String, child: Arc<RwLock<ModNode<T, U>>>, ) -> Result<()>
Adds the module to the module node.
Sourcepub fn remove_mod(&mut self, ident: &String) -> Result<()>
pub fn remove_mod(&mut self, ident: &String) -> Result<()>
Removes the module from the module node.
Sourcepub fn has_var(&self, ident: &String) -> bool
pub fn has_var(&self, ident: &String) -> bool
Returns true if the module node has the variable, otherwise false.
Sourcepub fn var(&self, ident: &String) -> Option<&T>
pub fn var(&self, ident: &String) -> Option<&T>
Returns the variable if the module node has the variable, otherwise None.
Sourcepub fn remove_var(&mut self, ident: &String)
pub fn remove_var(&mut self, ident: &String)
Removes the variable from module node.
Sourcepub fn parent(&self) -> Option<Arc<RwLock<ModNode<T, U>>>>
pub fn parent(&self) -> Option<Arc<RwLock<ModNode<T, U>>>>
Returns the parent if the module node if the module node has the parent, otherwise None.
Sourcepub fn mod_from(
root: &Arc<RwLock<ModNode<T, U>>>,
idents: &[String],
are_used_mods: bool,
) -> Result<Option<Arc<RwLock<ModNode<T, U>>>>>
pub fn mod_from( root: &Arc<RwLock<ModNode<T, U>>>, idents: &[String], are_used_mods: bool, ) -> Result<Option<Arc<RwLock<ModNode<T, U>>>>>
Returns the module for the identifiers of modules if the module exists, otherwise None.
If flag of used modules is set, the first identifier of module can refers to the used module.