A parser module.
Structs
- Parser
- A parser structure.
Functions
- parse
- Parses the script is refered by the path.
- parse_
with_ doc_ root_ mod - Parses the script is refered by the path with the root module of documentation.
- parse_
with_ doc_ root_ mod_ and_ doc_ current_ mod - Parses the script is refered by the path with the root module of documentation and the current module of documentation.