pub struct Parser<'a> { /* private fields */ }Expand description
A parser structure.
The parser parses tokens to a syntax tree that can be interpreted by an interpreter. The tokens are passed as an iterator that can be a lexer. Also, the parser can take the documentation comments from the lexer and then stores this comments as the documentation of modules and variables.
Implementations
Sourceimpl<'a> Parser<'a>
impl<'a> Parser<'a>
Sourcepub fn new_with_doc_root_mod_and_doc_current_mod(
path: Arc<String>,
tokens: &'a mut dyn DocIterator<Item = Result<(Token, Pos)>>,
doc_root_mod: Option<Arc<RwLock<ModNode<String, Option<String>>>>>,
doc_current_mod: Option<Arc<RwLock<ModNode<String, Option<String>>>>>,
) -> Self
pub fn new_with_doc_root_mod_and_doc_current_mod( path: Arc<String>, tokens: &'a mut dyn DocIterator<Item = Result<(Token, Pos)>>, doc_root_mod: Option<Arc<RwLock<ModNode<String, Option<String>>>>>, doc_current_mod: Option<Arc<RwLock<ModNode<String, Option<String>>>>>, ) -> Self
Creates a parser with the root module of documentation and the current module of documentation.
Also, this method takes the path that refers to the script and the tokens as the iterator. The parser stores the documentation if the root module of documentation is passed. If the current module of documentation is passed, the parser stores the documentation in this module instead of the root module of documentation.
Sourcepub fn new_with_doc_root_mod(
path: Arc<String>,
tokens: &'a mut dyn DocIterator<Item = Result<(Token, Pos)>>,
doc_root_mod: Option<Arc<RwLock<ModNode<String, Option<String>>>>>,
) -> Self
pub fn new_with_doc_root_mod( path: Arc<String>, tokens: &'a mut dyn DocIterator<Item = Result<(Token, Pos)>>, doc_root_mod: Option<Arc<RwLock<ModNode<String, Option<String>>>>>, ) -> Self
Creates a parser with the root module of documentation without the current module of documentation.
Sourcepub fn new(
path: Arc<String>,
tokens: &'a mut dyn DocIterator<Item = Result<(Token, Pos)>>,
) -> Self
pub fn new( path: Arc<String>, tokens: &'a mut dyn DocIterator<Item = Result<(Token, Pos)>>, ) -> Self
Creates a parser.