A package module.
Modules
- bitbucket
- A module of Bitbucket source.
- github
- A module of GitHub source.
- gitlab
- A module of GitLab source.
Structs
- Custom
Src - A structure of custom source.
- DocPaths
- A structure of documentation paths.
- Empty
Printer - A structure of empty printer.
- Manifest
- A structure of package manifest.
- Paths
- A structure of paths.
- PkgConfig
- A strcuture of package configuration.
- PkgInfo
- A structure of package information.
- PkgManager
- A structure of package manager.
- PkgName
- A structure of package name.
- StdPrinter
- A structure of standard printer.
- Versions
- A structure of package versions.
Enums
- SrcInfo
- An enumeration of source information.
- Version
SrcInfo - An enumeration of source information of version.
Constants
- USER_
AGENT_ HTTP_ HEADER - An User-Agent HTTP header for Curl.
Traits
- A printer trait.
- Source
- A source trait.
- Source
Create - A trait of source factory.
Functions
- cache_
dir - Returns a path to the cache directory.
- default_
src_ factories - Returns the factories of default sources.
- download_
pkg_ file - Downloads the package archive for the specified package.
- extract_
pkg_ file - Extracts the package archive for the specified package.
- index_
dir - Returns a path to the index directory.
- load_
opt_ src_ infos - Loads source informations from the file if the file exists, otherwise this function returns
None. - load_
opt_ version_ reqs - Loads version requirements from the file if the file exists, otherwise this function returns
None. - load_
opt_ versions - Loads versions from the file if the file exists, otherwise this function returns
None. - load_
src_ infos - Loads source informations from the file.
- load_
src_ infos_ or_ empty - Loads source informations from the file if the file exists, otherwise this function returns an empty hash map.
- load_
version_ reqs - Loads version requirements from the file.
- load_
version_ reqs_ or_ empty - Loads version requirements from the file if the file exists, otherwise this function returns an empty hash map.
- load_
versions - Loads versions from the file.
- load_
versions_ or_ empty - Loads versions from the file if the file exists, otherwise this function returns an empty hash map.
- pkg_
cache_ dir - Returns a path to the variable directory for the specified package.
- pkg_dir
- Returns a path to the package directory after extracting.
- pkg_
index_ dir - Returns a path to the index directory for the specified package.
- pkg_
part_ dir - Returns a path to the package directory while extracting.
- pkg_
tmp_ dir - Returns a path to the temporary directory for the specified package.
- read_
src_ infos - Reads source informations from the reader.
- read_
version_ reqs - Reads version requirements from the reader.
- read_
versions - Reads versions from the reader.
- save_
src_ infos - Saves the source informations to a file.
- save_
version_ reqs - Saves the version requirements to a file.
- save_
versions - Saves the versions to a file.
- tag_
name_ to_ version - Converts the tag name to a version.
- tmp_dir
- Returns a path to the temporary director.
- update_
pkg_ versions - Updates the package versions for the specified package.
- var_dir
- Returns a path to the variable directory.
- version_
to_ tag_ name - Converts the version to a tag name.
- write_
src_ infos - Writes the source informations to the writer.
- write_
version_ reqs - Writes the version requirements to the writer.
- write_
versions - Writes the versions to the writer.