pub fn load_version_reqs_or_empty<P: AsRef<Path>>( path: P, ) -> Result<HashMap<PkgName, VersionReq>>
Loads version requirements from the file if the file exists, otherwise this function returns an empty hash map.