pub enum HistogramValue {
Bool(bool),
Int(i64),
Float(f32),
String(Box<String>),
}Expand description
A structure of histogram value.
Variants
Bool(bool)
A boolean value.
Int(i64)
An integer number.
Float(f32)
A floating-point number.
String(Box<String>)
A string.
Implementations
Sourceimpl HistogramValue
impl HistogramValue
Sourcepub fn to_opt_bool(&self) -> Option<bool>
pub fn to_opt_bool(&self) -> Option<bool>
Converts the value to a boolean value if the value is an boolean type, otherwise this
method returns None.
Sourcepub fn to_opt_i64(&self) -> Option<i64>
pub fn to_opt_i64(&self) -> Option<i64>
Converts the value to an integer number if the value is an integer type or floating-point
type, otherwise this method returns None.
Sourcepub fn to_opt_f32(&self) -> Option<f32>
pub fn to_opt_f32(&self) -> Option<f32>
Converts the value to a floating-point number if the value is an integer type or
floating-point type, otherwise this method returns None.
Sourcepub fn to_opt_string(&self) -> Option<String>
pub fn to_opt_string(&self) -> Option<String>
Converts the value to a string if the value is a string type, otherwise this method
returns None.