pub struct TestResult { /* private fields */ }Expand description
A structure of test result.
The test result can be a success or a failure. A test error with a stack trace is in the result test if the test result is failure. Also, data from the standard output and the standard error stores in cursors which are in the test result.
Implementations
Sourceimpl TestResult
impl TestResult
Sourcepub fn new(
error_pair: Option<(Error, Vec<(Option<Value>, Pos)>)>,
stdout: Option<Arc<RwLock<Cursor<Vec<u8>>>>>,
stderr: Option<Arc<RwLock<Cursor<Vec<u8>>>>>,
) -> TestResult
pub fn new( error_pair: Option<(Error, Vec<(Option<Value>, Pos)>)>, stdout: Option<Arc<RwLock<Cursor<Vec<u8>>>>>, stderr: Option<Arc<RwLock<Cursor<Vec<u8>>>>>, ) -> TestResult
Creates a test result.
Sourcepub fn is_success(&self) -> bool
pub fn is_success(&self) -> bool
Returns true if the test result is success, otherwise false.
Sourcepub fn is_failure(&self) -> bool
pub fn is_failure(&self) -> bool
Returns true if the test result is failure, otherwise false.
Sourcepub fn error_pair(&self) -> Option<&(Error, Vec<(Option<Value>, Pos)>)>
pub fn error_pair(&self) -> Option<&(Error, Vec<(Option<Value>, Pos)>)>
Returns the test error with the stack trace if the test result is failure, otherwise
None.
Sourcepub fn stdout(&self) -> Option<&Arc<RwLock<Cursor<Vec<u8>>>>>
pub fn stdout(&self) -> Option<&Arc<RwLock<Cursor<Vec<u8>>>>>
Returns the cursor of standard output if the test result has the cursor of standard
output, otherwise None.
Sourcepub fn stderr(&self) -> Option<&Arc<RwLock<Cursor<Vec<u8>>>>>
pub fn stderr(&self) -> Option<&Arc<RwLock<Cursor<Vec<u8>>>>>
Returns the cursor of standard error if the test result has the cursor of standard error,
otherwise None.
Sourcepub fn has_stdout_data(&self) -> Result<bool>
pub fn has_stdout_data(&self) -> Result<bool>
Returns true if the test result has data from the standard output, otherwise false.
Sourcepub fn has_stderr_data(&self) -> Result<bool>
pub fn has_stderr_data(&self) -> Result<bool>
Returns true if the test result has data from the standard error, otherwise false.