A module of utilities.
Structs
- Pushback
Iter - A structure of pushback iterator.
Functions
- eprint_
error - Prints the error to the standard error.
- eprint_
error_ with_ stack_ trace - Prints the error with the stac trace to the standard error.
- matrix_
abs - Calculates absolute values of the
amatrix elements. - matrix_
acos - Calculates arccosine function for the
amatrix. - matrix_
acosh - Calculates inverse hyperbolic cosine function for the
amatrix. - matrix_
add - Adds the
bmatrix to theamatrix. - matrix_
add_ for_ scalar - Adds the
bscalar to theamatrix. - matrix_
asin - Calculates arcsine function for the
amatrix. - matrix_
asinh - Calculates inverse hyperbolic sine function for the
amatrix. - matrix_
atan - Calculates arctangent function for the
amatrix. - matrix_
atan2 - Calculates arctangent function for the
amatrix elements and thebmatrix elements. - matrix_
atan2_ for_ scalar - Calculates arctangent function for the
amatrix elements and thebscalar. - matrix_
atanh - Calculates inverse hyperbolic tangent function for the
amatrix. - matrix_
backend_ name - Returns the backend name.
- matrix_
ceil - Calculates ceil function for the
amatrix. - matrix_
cos - Calculates cosine function for the
amatrix. - matrix_
cosh - Calculates hyperbolic cosine function for the
amatrix. - matrix_
create_ and_ set_ elems - Creates a matrix and sets the matrix elements.
- matrix_
create_ and_ set_ zeros - Creates a matrix and sets the matrix elements on zeros.
- matrix_
div_ elems - Divides the
amatrix elements by thebmatrix. - matrix_
div_ for_ scalar - Divides the
amatrix by thebscalar. - matrix_
elems_ and_ transpose_ flag - Returns the elements and the transpose flag of matrix.
- matrix_
exp - Calculates exponential function for the
amatrix elements. - matrix_
floor - Calculates floor function for the
amatrix. - matrix_
ln - Calculates natural logarithm of the
amatrix elements. - matrix_
log2 - Calculates base 2 logarithm of the
amatrix elements. - matrix_
log10 - Calculates base 10 logarithm of the
amatrix elements. - matrix_
max - Finds maximum values between the
amatrix elements and thebmatrix elements. - matrix_
max_ for_ scalar - Finds maximum values between the
amatrix elements and thebscalar. - matrix_
min - Finds minimum values between the
amatrix elements and thebmatrix elements. - matrix_
min_ for_ scalar - Finds minimum values between the
amatrix elements and thebscalar. - matrix_
mul - Multiplies the
amatrix by thebmatrix. - matrix_
mul_ elems - Multiplies the
amatrix elements by thebmatrix. - matrix_
mul_ for_ scalar - Multiplies the
amatrix by thebscalar. - matrix_
pow - Raises the
amatrix elements to the power of thebmatrix elements. - matrix_
pow_ for_ scalar - Raises the
amatrix elements to the power of thebscalar. - matrix_
ratan2_ for_ scalar - Calculates arctangent function for the
bscalar and theamatrix elements. - matrix_
rdiv_ for_ scalar - Divides the
bscalar by theamatrix elements. - matrix_
really_ transpose - Indeed transposes the
amatrix. - matrix_
repeat - Repeats the
avector as column or a row. - matrix_
round - Calculates round function for the
amatrix. - matrix_
rpow_ for_ scalar - Raises the
bscalar to the power of theamatrix elements. - matrix_
rsub_ for_ scalar - Subtracts the
amatrix from thebscalar. - matrix_
sigmoid - Calculates sigmoid function for the
amatrix. - matrix_
signum - Calculates signum function for the
amatrix. - matrix_
sin - Calculates sine function for the
amatrix. - matrix_
sinh - Calculates hyperbolic sine function for the
amatrix. - matrix_
softmax - Calculates softmax function for the
amatrix. - matrix_
sqrt - Calculates square roots of the
amatrix elements. - matrix_
sub - Subtracts the
bmatrix from theamatrix. - matrix_
sub_ for_ scalar - Subtracts the
bscalar from theamatrix. - matrix_
swish - Calculates swish function for the
amatrix. - matrix_
tan - Calculates tangent function for the
amatrix. - matrix_
tanh - Calculates hyperbolic tangent function for the
amatrix. - matrix_
to_ matrix_ array - Converts the
amatrix to the matrix array. - matrix_
trunc - Calculates trunc function for the
amatrix. - mutex_
lock - Locks the mutex.
- receiver_
recv - Receives an object from the receiver.
- rw_
lock_ read - Locks the reader-writer lock with shared read access.
- rw_
lock_ write - Locks the reader-writer lock with exclusive write access.
- str_
to_ ident - Converts the string slice to an identifier.
- str_
to_ url_ name - Converts the string slice to an URL name.
- str_
without_ crlf - Returns the string slice without the LF character and the CRLF character sequence.