pub enum SingleVersionReq {
Wildcard,
Pair(VersionOp, Version),
}Expand description
An enumeration of single version requirement.
The single version requirement can have one version with a version operator or can be a wildcard. A version requirement uses many single version requirements which can be matched to a version while matching.
Variants
Implementations