pub struct VersionReq { /* private fields */ }Expand description
A structure of version requirement.
The version requirement can be matched to the version and can contain many single version
requirements which can be matched to version while matching. The version requirements are used
to check versions by a package manager and a reqver built-in function.
Implementations
Sourceimpl VersionReq
impl VersionReq
Sourcepub fn new(single_reqs: Vec<SingleVersionReq>) -> Self
pub fn new(single_reqs: Vec<SingleVersionReq>) -> Self
Creates a version requirement.
Sourcepub fn single_reqs(&self) -> &[SingleVersionReq]
pub fn single_reqs(&self) -> &[SingleVersionReq]
Returns the single version requirements.